/**
//
//    Urbi
//
#include <urbi/uobject.hh>

class MyAdder: public urbi::UObject
{
  public:
	// The class must have a single constructor taking a string. 
    MyAdder(const std::string& str);
    int init();
 
   // Our variable. 
   urbi::UVar v; 
 
   // Our method. 
   double add (double); 
};


// the constructor defines what is available from Urbi 
MyAdder::MyAdder(const std::string& s)
 : urbi::UObject(s)  // required 
{
  // Bind the variable. 
  UBindVar (MyAdder, v); 
 
  // Bind the function. 
  UBindFunction (MyAdder, add); 

  UBindFunction(MyAdder, init);
};

int MyAdder::init()
{
  return 0;
};

 
double 
MyAdder::add (double rhs) 
{ 
  return ((double)v + rhs); 
}


UStart(MyAdder);
/**/

//
//   Urbi
//
#include <urbi/uobject.hh>

#include "serial/serial.h"

class ArServo: public urbi::UObject
{
public:
	// The class must have a single constructor taking a string. 
	ArServo(const std::string& str);
	~ArServo();
	int init();

	// Our variable. 
	urbi::UVar val; 
	urbi::UVar pin;

	Serial sg;

	// Our method. 
	int port(int port, int rate);
	double set(int angle); 
};


// the constructor defines what is available from Urbi 
ArServo::ArServo(const std::string& s)
: urbi::UObject(s)  // required 
{
	// Bind the variable. 
	UBindVar (ArServo, val); 
	UBindVar (ArServo, pin);

	// Bind the function. 
	UBindFunction (ArServo, port);
	UBindFunction (ArServo, set); 

	UBindFunction(ArServo, init);
};

ArServo::~ArServo()
{
	if(sg.IsConnected()){
		sg.Close();
	}
};

int ArServo::init()
{
	pin=0;
	return 0;
};

int ArServo::port(int port, int rate=9600)
{
	bool b = sg.Open(port, rate);
	if(!b){
		printf("[!] Error: cant open COM-port!\n");
		return 1;
	}
	printf("[i] ok\n");
	return 0;
};

double 
ArServo::set (int angle) 
{
	if(!sg.IsConnected()){
		printf("[!] Error: open COM-port first!\n");
		return 0;
	}
	char buf[3];
	buf[0] = 0xE0 | (int)pin;
	buf[1] = angle & 0x7F;
	buf[2] = (angle >> 7) & 0x7F;
	sg.Send(buf, 3);
	Sleep(100);
	val=angle;
	return angle; 
};

UStart(ArServo);